@@ -2,8 +2,8 @@
 
    This file is part of the UPX executable compressor.
 
-   Copyright (C) 1996-2010 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1996-2010 Laszlo Molnar
+   Copyright (C) 1996-2013 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2013 Laszlo Molnar
    All Rights Reserved.
 
    UPX and the UCL library are free software; you can redistribute them
@@ -898,6 +898,9 @@ static int do_option(int optc, const char *arg)
     case 674:
         opt->o_unix.unmap_all_pages = true;  // val ?
         break;
+    case 675:
+        opt->o_unix.preserve_build_id = true;
+        break;
 
     case '\0':
         return -1;
@@ -1048,6 +1051,7 @@ static const struct mfx_option longopts[] =
     {"OpenBSD",          0x10, 0, 669},
     {"openbsd",          0x10, 0, 669},
     {"unmap-all-pages",  0x10, 0, 674},     // linux /proc/self/exe vanishes
+    {"preserve-build-id",   0, 0, 675},
     // watcom/le
     {"le",               0x10, 0, 620},     // produce LE output
     // win32/pe
@@ -1285,9 +1289,13 @@ static bool test(void)
     COMPILE_TIME_ASSERT_ALIGNED1(test2_t)
     COMPILE_TIME_ASSERT(sizeof(t2) == 7 + 21*sizeof(T))
 #if defined(__acc_alignof)
+#if (ACC_CC_CLANG && ACC_ARCH_AMD64)
+    // CBUG: clang-2.8 bug in 64-bit mode
+#else
     COMPILE_TIME_ASSERT(__acc_alignof(t1) == 1)
     COMPILE_TIME_ASSERT(__acc_alignof(t2) == 1)
 #endif
+#endif
 #if 1 && (ACC_CC_WATCOMC)
     test1_t t11; COMPILE_TIME_ASSERT(sizeof(t11.a) <= sizeof(t11.b))
     test2_t t22; COMPILE_TIME_ASSERT(sizeof(t22.a) <= sizeof(t22.b))
@@ -1366,7 +1374,7 @@ void upx_sanity_check(void)
     assert(TestBELE<BE64>::test());
     {
     static const unsigned char dd[32]
-#if 1 && (ACC_CC_GNUC || ACC_CC_INTELC || ACC_CC_PATHSCALE) && defined(__ELF__)
+#if 1 && (ACC_CC_CLANG || ACC_CC_GNUC || ACC_CC_INTELC || ACC_CC_PATHSCALE) && defined(__ELF__)
         __attribute__((__aligned__(16)))
 #endif
         = { 0, 0, 0, 0, 0, 0, 0,
@@ -1400,7 +1408,7 @@ void upx_sanity_check(void)
     assert(get_le32(d) == 0xfcfdfeff);
     assert(bele->get32(d) == 0xfcfdfeff);
     assert(get_le32_signed(d) == -50462977);
-    assert(get_le64_signed(d) == ACC_INT64_C(-506097522914230529));
+    assert(get_le64_signed(d) == UPX_INT64_C(-506097522914230529));
     assert(find_be16(d, 2, 0xfffe) == 0);
     assert(find_le16(d, 2, 0xfeff) == 0);
     assert(find_be32(d, 4, 0xfffefdfc) == 0);
@@ -1409,7 +1417,7 @@ void upx_sanity_check(void)
     assert(get_be16_signed(d) == 32638);
     assert(get_be24_signed(d) == 8355453);
     assert(get_be32_signed(d) == 2138996092);
-    assert(get_be64_signed(d) == ACC_INT64_C(9186918263483431288));
+    assert(get_be64_signed(d) == UPX_INT64_C(9186918263483431288));
     }
 #endif
 }
@@ -1434,6 +1442,9 @@ int __acc_cdecl_main main(int argc, char *argv[])
 #if 0 && defined(__DJGPP__)
     // LFN=n may cause problems with 2.03's _rename and mkdir under WinME
     putenv("LFN=y");
+#endif
+#if (ACC_OS_WIN32 || ACC_OS_WIN64) && (ACC_CC_MSC) && defined(_WRITE_ABORT_MSG) && defined(_CALL_REPORTFAULT)
+    _set_abort_behavior(_WRITE_ABORT_MSG, _WRITE_ABORT_MSG | _CALL_REPORTFAULT);
 #endif
     acc_wildargv(&argc, &argv);
 
