@@ -2,8 +2,8 @@
 
    This file is part of the UPX executable compressor.
 
-   Copyright (C) 1996-2010 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1996-2010 Laszlo Molnar
+   Copyright (C) 1996-2013 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2013 Laszlo Molnar
    All Rights Reserved.
 
    UPX and the UCL library are free software; you can redistribute them
@@ -360,7 +360,7 @@ void PackWcle::preprocessFixups()
                     //if (memcmp(iimage+jc+fixp2,fix+5,(fix[1] & 0x10) ? 4 : 2))
                     //    throwCantPack("illegal fixup offset");
 
-                    // work around an pmwunlite bug: remove duplicated fixups
+                    // work around a pmwunlite bug: remove duplicated fixups
                     // FIXME: fix the other cases too
                     if (rc == 0 || get_le32(rl+4*rc-4) != jc+fixp2)
                     {
@@ -646,7 +646,7 @@ void PackWcle::decodeFixups()
         // 32 bit offset fixups
         while (get_le32(wrkmem+4*jc) < ic*mps)
         {
-            if (ic > 1 && ((get_le32(wrkmem+4*(jc-2))+3) & (mps-1)) < 3) // cross page fixup?
+            if (jc > 1 && ((get_le32(wrkmem+4*(jc-2))+3) & (mps-1)) < 3) // cross page fixup?
             {
                 r = get_le32(oimage+get_le32(wrkmem+4*(jc-2)));
                 fp[0] = 7;
@@ -823,7 +823,9 @@ void PackWcle::unpack(OutputFile *fo)
 
         Filter ft(ph.level);
         ft.init(ph.filter, text_vaddr);
-        ft.cto = (unsigned char) (ph.version < 11 ? (get_le32(oimage+ph.u_len-9) >> 24) : ph.filter_cto);
+        ft.cto = (unsigned char) ph.filter_cto;
+        if (ph.version < 11)
+            ft.cto = (unsigned char) (get_le32(oimage+ph.u_len-9) >> 24);
         ft.unfilter(oimage+text_vaddr, text_size);
     }
 
