@@ -2,8 +2,8 @@
 
    This file is part of the UPX executable compressor.
 
-   Copyright (C) 1996-2011 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1996-2011 Laszlo Molnar
+   Copyright (C) 1996-2013 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2013 Laszlo Molnar
    All Rights Reserved.
 
    UPX and the UCL library are free software; you can redistribute them
@@ -181,7 +181,8 @@ protected:
     void compressWithFilters(Filter *ft,
                              const unsigned overlap_range,
                              const upx_compress_config_t *cconf,
-                             int filter_strategy = 0);
+                             int filter_strategy = 0,
+                             int inhibit_compression_check = 0);
     void compressWithFilters(Filter *ft,
                              const unsigned overlap_range,
                              const upx_compress_config_t *cconf,
@@ -189,7 +190,8 @@ protected:
                              unsigned filter_buf_off,
                              unsigned compress_ibuf_off,
                              unsigned compress_obuf_off,
-                             const upx_bytep hdr_ptr, unsigned hdr_len);
+                             const upx_bytep hdr_ptr, unsigned hdr_len,
+                             int inhibit_compression_check = 0);
     // real compression driver
     void compressWithFilters(upx_bytep i_ptr, unsigned i_len,
                              upx_bytep o_ptr,
@@ -198,7 +200,8 @@ protected:
                              Filter *ft,
                              const unsigned overlap_range,
                              const upx_compress_config_t *cconf,
-                             int filter_strategy);
+                             int filter_strategy,
+                             int inhibit_compression_check = 0);
 
     // util for verifying overlapping decompresion
     //   non-destructive test
@@ -281,16 +284,20 @@ protected:
     void checkPatch(void *b, int blen, int boff, int size);
 
     // relocation util
+    static upx_byte *optimizeReloc(upx_byte *in,unsigned relocnum,upx_byte *out,upx_byte *image,int bs,int *big, int bits);
+    static unsigned unoptimizeReloc(upx_byte **in,upx_byte *image,MemBuffer *out,int bs, int bits);
     static upx_byte *optimizeReloc32(upx_byte *in,unsigned relocnum,upx_byte *out,upx_byte *image,int bs,int *big);
     static unsigned unoptimizeReloc32(upx_byte **in,upx_byte *image,MemBuffer *out,int bs);
+    static upx_byte *optimizeReloc64(upx_byte *in,unsigned relocnum,upx_byte *out,upx_byte *image,int bs,int *big);
+    static unsigned unoptimizeReloc64(upx_byte **in,upx_byte *image,MemBuffer *out,int bs);
 
     // target endianness abstraction
-    unsigned get_te16(const void *p)        const { return bele->get16(p); }
-    unsigned get_te32(const void *p)        const { return bele->get32(p); }
-    acc_uint64l_t get_te64(const void *p)   const { return bele->get64(p); }
-    void set_te16(void *p, unsigned v)      const { bele->set16(p, v); }
-    void set_te32(void *p, unsigned v)      const { bele->set32(p, v); }
-    void set_te64(void *p, acc_uint64l_t v) const { bele->set64(p, v); }
+    unsigned get_te16(const void *p)       const { return bele->get16(p); }
+    unsigned get_te32(const void *p)       const { return bele->get32(p); }
+    upx_uint64_t get_te64(const void *p)   const { return bele->get64(p); }
+    void set_te16(void *p, unsigned v)     const { bele->set16(p, v); }
+    void set_te32(void *p, unsigned v)     const { bele->set32(p, v); }
+    void set_te64(void *p, upx_uint64_t v) const { bele->set64(p, v); }
 
 protected:
     const N_BELE_RTP::AbstractPolicy *bele; // target endianness
